function [p,A]=pLUinplace_Mat(A)
% permuted LU factorization for N-by-n-by-n 3D-array A,  
%   see Golub G.H & Van Loan C.F., Matrix Computations (3rd E.d) Algorithm 3.4.1, page 112 
%     P_k*A_k=L_k*U_k   where A_k=A(k,:,:) 
% Returns 
%   - A, the modify n-by-n matrix such that 
%       L=fc_linalg3D.tril(A,-1)+fc_linalg3D.eye(N,n), U=fc_linalg3D.triu(A)
%     One ca also use [L,U]=fc_linalg3D.fact.LUfrominplace(A)
%   - p, the permutation indices N-by-n array such that the n-by-n permutation matrix P_k is defined by
%        P_k(i,p(k,i))=1 for all i in 1:n
%        P_k(i,j)=0 otherwize
%    in Matlab/Octave to build the N-by-n-by-n 3D-array P: 
%       P=zeros(N,n,n); 
%       P(sub2ind(size(P),repmat([1:N]',1,n),repmat(1:n,N,1),p))=1
%    or
%       P=fc_linalg3D.fact.permInd2Mat(p)
  assert( fc_linalg3D.is3Darray(A) )
  [N,m,n]=size(A);
  assert( m==n )
  p=repmat(1:m,N,1);
  for k=1:N
    [p(k,:),A(k,:,:)]=fc_linalg3D.fact.pLUinplace(squeeze(A(k,:,:)));
  end
  if nargout==1, p={p,A};end
end
